<!-- AUTOGENERATED BY glean_parser.  DO NOT EDIT. -->

# Metrics
This document enumerates the metrics collected by this project.
This project may depend on other projects which also collect metrics.
This means you might have to go searching through the dependency tree to get a full picture of everything collected by this project.

# Pings

 - [usage](#usage)


## usage

This ping is intended to provide a measure of the usage of MozPhab. It's generated after a command is finished.


This ping includes the [client id](https://mozilla.github.io/glean/book/user/pings/index.html#the-client_info-section).

**Data reviews for this ping:**

- <https://bugzilla.mozilla.org/show_bug.cgi?id=1621025#c21>

**Bugs related to this ping:**

- <http://bugzilla.mozilla.org/1621025/>

The following metrics are added to the ping:

| Name | Type | Description | Data reviews | Extras | Expiration |
| --- | --- | --- | --- | --- | --- |
| mozphab.environment.distribution_version |[string](https://mozilla.github.io/glean/book/user/metrics/string.html) |Version number of the Operating System or distribution name and version for Linux.  |[1](https://bugzilla.mozilla.org/show_bug.cgi?id=1621025#c21)||never |
| mozphab.environment.python_version |[string](https://mozilla.github.io/glean/book/user/metrics/string.html) |Python version  |[1](https://bugzilla.mozilla.org/show_bug.cgi?id=1621025#c21)||never |
| mozphab.environment.vcs.name |[string](https://mozilla.github.io/glean/book/user/metrics/string.html) |Name of the underlying version control system  |[1](https://bugzilla.mozilla.org/show_bug.cgi?id=1621025#c21)||never |
| mozphab.environment.vcs.version |[string](https://mozilla.github.io/glean/book/user/metrics/string.html) |Version of the underlying version control system  |[1](https://bugzilla.mozilla.org/show_bug.cgi?id=1621025#c21)||never |
| mozphab.submission.commits_count |[counter](https://mozilla.github.io/glean/book/user/metrics/counter.html) |A total number of commits in the stack.  |[1](https://bugzilla.mozilla.org/show_bug.cgi?id=1621025#c21)||never |
| mozphab.submission.files_count |[counter](https://mozilla.github.io/glean/book/user/metrics/counter.html) |A total number of files submitted.  |[1](https://bugzilla.mozilla.org/show_bug.cgi?id=1621025#c21)||never |
| mozphab.submission.files_size |[memory_distribution](https://mozilla.github.io/glean/book/user/metrics/memory_distribution.html) |A distributed size of all files in the submitted stack  |[1](https://bugzilla.mozilla.org/show_bug.cgi?id=1621025#c21)||never |
| mozphab.submission.preparation_time |[timespan](https://mozilla.github.io/glean/book/user/metrics/timespan.html) |Time spent on preparing the commit stack.  |[1](https://bugzilla.mozilla.org/show_bug.cgi?id=1621025#c21)||never |
| mozphab.submission.process_time |[timespan](https://mozilla.github.io/glean/book/user/metrics/timespan.html) |Time spent on performing the submission. This metric will be null if the users decides to discontinue submission process after the preparation step.  |[1](https://bugzilla.mozilla.org/show_bug.cgi?id=1621025#c21)||never |
| mozphab.usage.arcanist |[boolean](https://mozilla.github.io/glean/book/user/metrics/boolean.html) |True if MozPhab was forced to use Arcanist  |[1](https://bugzilla.mozilla.org/show_bug.cgi?id=1621025#c21)||never |
| mozphab.usage.command |[string](https://mozilla.github.io/glean/book/user/metrics/string.html) |Command used to run MozPhab, e.g. `submit` or `patch`.  |[1](https://bugzilla.mozilla.org/show_bug.cgi?id=1621025#c21)||never |
| mozphab.usage.command_time |[timespan](https://mozilla.github.io/glean/book/user/metrics/timespan.html) |Time spent on performing the command  |[1](https://bugzilla.mozilla.org/show_bug.cgi?id=1621025#c21)||never |
| mozphab.usage.override_switch |[boolean](https://mozilla.github.io/glean/book/user/metrics/boolean.html) |True if a --force switch was used to override validation  |[1](https://bugzilla.mozilla.org/show_bug.cgi?id=1621025#c21)||never |
| mozphab.user.id |[uuid](https://mozilla.github.io/glean/book/user/metrics/uuid.html) |Unique identifier of each MozPhab user. The default `client_id` will change if the user would delete the `telemetry-data` directory. The `user.id` metric is created by hashing the email, which will be the same for all MozPhab installations. We store the user identification in a file that is updated every week. We want to change the `user.id` metric when the user changes an email.  |[1](https://bugzilla.mozilla.org/show_bug.cgi?id=1621025#c21)||never |
| mozphab.user.installation |[uuid](https://mozilla.github.io/glean/book/user/metrics/uuid.html) |Unique identifier of each MozPhab installation. A user might install the application on multiple machines/profiles.  |[1](https://bugzilla.mozilla.org/show_bug.cgi?id=1621025#c21)||never |


<!-- AUTOGENERATED BY glean_parser.  DO NOT EDIT. -->

